@@ -24,7 +24,7 @@ class PortfolioInfo:
             select t1."portfolioCycleId",t1.username,t1.symbol,COALESCE("latestMatchPrice",0) as "latestMatchPrice",
                 "totalAmount",CASE WHEN "forceSellAmount" > "availableAmount" THEN 0 ELSE "availableAmount" - "forceSellAmount"  END as "availableAmount",
                 "pendingAmount","scheduledAmount", "averageMatchedPrice","targetPercent",
-                "balance","initBalance", t4."cutoffDate", t4."startDate",t4."endDate", "forceSellAmount" , "portfolioType"
+                "balance","initBalance", t4."cutoffDate", t4."startDate",t4."endDate", "forceSellAmount" , t1."portfolioType"
                 from "portfolio" t1
                 left join "symbol_info" t2 on t1.symbol = t2.symbol
                 left join "portfolio_cycle" t4 on t1."portfolioCycleId" = t4.id
